ModeledComputeSnapshot

Struct ModeledComputeSnapshot 

pub struct ModeledComputeSnapshot {
    pub accepted: usize,
    pub completed: usize,
    pub queued: usize,
    pub queued_bytes: u64,
    pub resident_allocations: usize,
    pub live_allocations: usize,
    pub resident_bytes: u64,
    pub evictions: usize,
    pub segments: usize,
    pub readbacks: usize,
    pub materialization_failures: usize,
    pub batch_flushes: usize,
}
Snapshot of modeled executor counters.

Fields

accepted: usize

Submissions accepted by the modeled executor.

completed: usize

Submissions completed by the modeled executor.

queued: usize

Submissions waiting for flush evidence.

queued_bytes: u64

Bytes currently waiting for flush evidence.

resident_allocations: usize

Resident allocations produced by this executor.

live_allocations: usize

Resident allocations still present in the modeled bounded pool.

resident_bytes: u64

Resident bytes still present in the modeled bounded pool.

evictions: usize

Resident allocations evicted by the bounded pool.

segments: usize

Total resident segments allocated.

readbacks: usize

Resident readbacks observed through modeled storage.

materialization_failures: usize

Stable resident materialization failures.

batch_flushes: usize

Automatic bounded-batch flushes performed before accepting more work.