pub struct ModeledResidentStorage { /* private fields */ }Expand description
Resident storage that models readback into host tensor cells.
Implementations
Sourceimpl ModeledResidentStorage
impl ModeledResidentStorage
Sourcepub fn allocation(&self) -> &ResidentHandle
pub fn allocation(&self) -> &ResidentHandle
Returns the resident allocation handle.
Sourcepub fn segments(&self) -> &[ModeledResidentSegment]
pub fn segments(&self) -> &[ModeledResidentSegment]
Returns the segmented resident layout for this allocation.
Sourcepub fn resident_tensor(&self) -> Option<Tensor>
pub fn resident_tensor(&self) -> Option<Tensor>
Rebuilds a canonical host tensor without counting a user readback.