ModeledComputeProfile

Struct ModeledComputeProfile 

pub struct ModeledComputeProfile {
    pub provider: String,
    pub max_queue_depth: usize,
    pub max_queue_bytes: u64,
    pub max_resident_bytes: u64,
    pub segment_tile_bytes: u64,
    pub max_storage_binding_bytes: u64,
    pub submission_deadline_ticks: u64,
    pub fault: Option<ModeledComputeFault>,
    pub auto_flush_batches: bool,
}
Configuration for a modeled compute site.

Fields

provider: String

Stable provider label.

max_queue_depth: usize

Maximum accepted submissions waiting for flush evidence.

max_queue_bytes: u64

Maximum bytes accepted into the submission queue.

max_resident_bytes: u64

Maximum modeled resident bytes retained by the site.

segment_tile_bytes: u64

Largest tile used before a tensor is segmented.

max_storage_binding_bytes: u64

Checked storage binding boundary used by the modeled layout.

submission_deadline_ticks: u64

Maximum modeled ticks a submission may wait before rejection.

fault: Option<ModeledComputeFault>

Optional deterministic fault.

auto_flush_batches: bool

Flush queued submissions before rejecting a bounded batch overflow.